<?php

namespace App\Distributor\Metrics;

use Dcat\Admin\Widgets\Metrics\Round;
use Illuminate\Http\Request;
use App\Models\DistMessage as DistMessageModel;

class DistMessage extends Round
{
    /**
     * 初始化卡片内容
     */
    protected function init()
    {
        parent::init();

        // 卡片内容宽度
        $this->contentWidth(12, 0);
        $this->title('Messages');

    }

    /**
     * 处理请求
     *
     * @param Request $request
     *
     * @return mixed|void
     */
    public function handle(Request $request)
    {
        // 获取最新的10条消息
        $messages = DistMessageModel::latest()->take(10)->get();


        // 卡片内容
        $this->withContent($messages);
    }

    /**
     * 卡片内容.
     *
     * @param \Illuminate\Support\Collection $messages
     *
     * @return $this
     */
    public function withContent($messages)
    {
        $content = '';

        foreach ($messages as $message) {
            $content .= <<<HTML
<div class="chart-info d-flex justify-content-between mb-1">
    <div class="series-info d-flex align-items-center">
        . <a href="/dist/messages/{$message->id}"><span class="text-bold-600 ml-50">{$message->title} ({$message->created_at->toDateString()})</span>
        </a>
    </div>
    <div class="product-result">
        <span>{$message->status}</span>
    </div>
</div>
HTML;
        }

        return $this->content(
            <<<HTML

<div class="col-12 d-flex flex-column flex-wrap text-center" style="">
    {$content}
</div>
HTML
        );
    }
}
